@@ -1,6 +1,5 @@
 import os
 from plato.models.task import CustomEvalConfig
-from pydantic import Field
 from plato.models import PlatoTask, EvaluationResult
 from typing import Coroutine, List, Optional, Type, Dict, Any, TYPE_CHECKING
 import time
@@ -51,6 +50,7 @@ class PlatoEnvironment:
         env_id: Optional[str] = None,
         alias: Optional[str] = None,
         active_session: Optional[str] = None,
+        fast: bool = False,
     ):
         self._client = client
         self.id = id
@@ -59,8 +59,9 @@ class PlatoEnvironment:
         self._run_session_id = None
         self._heartbeat_task = None
         self._run_session_id = active_session
+        self.fast = fast
 
-    async def login(self, page: Page) -> None:
+    async def login(self, page: Page, throw_on_login_error: bool = False) -> None:
         """Login to the environment using authentication config.
 
         Args:
@@ -69,14 +70,22 @@ class PlatoEnvironment:
         from plato.models.flow import Simulator
         from plato.flow_executor import FlowExecutor
 
-        # Create S3 session and client
+        # Create S3 client configured for unsigned requests (public buckets)
+        try:
+            from botocore.config import Config  # type: ignore
+            from botocore import UNSIGNED  # type: ignore
+        except ImportError:
+            raise PlatoClientError("aioboto3 and botocore are required for S3 access")
+
         session = aioboto3.Session()
 
         temp_dir = os.path.join("/tmp", self.env_id)
         os.makedirs(temp_dir, exist_ok=True)
 
         # Download the scripts file from S3
-        async with session.client("s3") as s3_client:
+        async with session.client(
+            "s3", config=Config(signature_version=UNSIGNED)
+        ) as s3_client:
             await s3_client.download_file(
                 "plato-sim-scripts",
                 os.path.join(self.env_id, "scripts.yaml"),
@@ -102,7 +111,12 @@ class PlatoEnvironment:
             raise PlatoClientError("No login flow found")
 
         flow_executor = FlowExecutor(page, login_flow, base_dataset, logger=logger)
-        await flow_executor.execute_flow()
+        success = await flow_executor.execute_flow()
+        if not success:
+            if throw_on_login_error:
+                raise PlatoClientError("Failed to login")
+            else:
+                logger.warning("Failed to login")
 
     async def wait_for_ready(self, timeout: Optional[float] = None) -> None:
         """Wait for the environment to be ready.
@@ -119,7 +133,7 @@ class PlatoEnvironment:
         """
         start_time = time.time()
         base_delay = 0.5  # Starting delay in seconds
-        max_delay = 8.0  # Maximum delay between retries
+        max_delay = 2.0  # Maximum delay between retries
 
         # wait for the job to be running
         current_delay = base_delay
@@ -215,6 +229,7 @@ class PlatoEnvironment:
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
         load_authenticated: bool = False,
+        **kwargs,
     ) -> str:
         """Reset the environment with an optional new task.
 
@@ -227,7 +242,7 @@ class PlatoEnvironment:
             str: The environment is reset and a new run session is created.
         """
         response = await self._client.reset_environment(
-            self.id, task, agent_version, load_authenticated
+            self.id, task, agent_version, load_authenticated, **kwargs
         )
         if task:
             self._current_task = task
@@ -420,7 +435,7 @@ class PlatoEnvironment:
                 reason=result.get("reason", None),
                 diffs=result.get("diffs", None),
                 expected_mutations=result.get("expected_mutations", None),
-                actual_mutations=result.get("actual_mutations", None),
+                actual_mutations=result.get("mutations", None),
             )
 
     async def log(self, log: dict, type: str = "info") -> None:
@@ -473,11 +488,14 @@ class PlatoEnvironment:
             # Extract the base domain from the base_url
             if "localhost:8080" in self._client.base_url:
                 proxy_server = "http://localhost:8888"
+            elif "dev.plato.so" in self._client.base_url:
+                proxy_server = "https://dev.proxy.plato.so"
             elif "staging.plato.so" in self._client.base_url:
                 proxy_server = "https://staging.proxy.plato.so"
             elif (
                 "plato.so" in self._client.base_url
                 and "staging" not in self._client.base_url
+                and "dev" not in self._client.base_url
             ):
                 proxy_server = "https://proxy.plato.so"
             else:
@@ -497,6 +515,7 @@ class PlatoEnvironment:
         Returns:
             str: The public URL for this environment based on the deployment environment.
                  Uses alias if available, otherwise uses environment ID.
+                 - Dev: https://{alias|env.id}.dev.sims.plato.so
                  - Staging: https://{alias|env.id}.staging.sims.plato.so
                  - Production: https://{alias|env.id}.sims.plato.so
                  - Local: http://localhost:8081/{alias|env.id}
@@ -511,11 +530,14 @@ class PlatoEnvironment:
             # Determine environment based on base_url
             if "localhost:8080" in self._client.base_url:
                 return f"http://localhost:8081/{identifier}"
+            elif "dev.plato.so" in self._client.base_url:
+                return f"https://{identifier}.dev.sims.plato.so"
             elif "staging.plato.so" in self._client.base_url:
                 return f"https://{identifier}.staging.sims.plato.so"
             elif (
                 "plato.so" in self._client.base_url
                 and "staging" not in self._client.base_url
+                and "dev" not in self._client.base_url
             ):
                 return f"https://{identifier}.sims.plato.so"
             else:
@@ -554,7 +576,9 @@ class PlatoEnvironment:
         return await self._client.backup_environment(self.id)
 
     @staticmethod
-    async def from_id(client: "Plato", id: str) -> "PlatoEnvironment":
+    async def from_id(
+        client: "Plato", id: str, fast: bool = False
+    ) -> "PlatoEnvironment":
         """Create a new environment from an ID.
 
         Returns:
@@ -564,9 +588,11 @@ class PlatoEnvironment:
         active_session = None
         try:
             active_session = await client.get_active_session(id)
-        except Exception as e:
+        except Exception:
             logger.warning(
                 f"No active session found for job {id}, remember to reset the environment to use / evaluate."
             )
 
-        return PlatoEnvironment(client, id, active_session=active_session)
+        env = PlatoEnvironment(client, id, active_session=active_session, fast=fast)
+        await env._start_heartbeat()
+        return env
