@@ -78,6 +78,8 @@ class Plato:
         env_config: Optional[Dict[str, Any]] = None,
         keepalive: bool = False,
         alias: Optional[str] = None,
+        fast: bool = False,
+        version: Optional[str] = None,
     ) -> PlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -92,6 +94,8 @@ class Plato:
             env_config (Optional[Dict[str, Any]]): Environment configuration.
             keepalive (bool): If true, jobs will not be killed due to heartbeat failures.
             alias (Optional[str]): Optional alias for the job group.
+            fast (bool): Fast mode flag.
+            version (Optional[str]): Optional version of the environment.
 
         Returns:
             PlatoEnvironment: The created environment instance.
@@ -114,6 +118,8 @@ class Plato:
                 "record_actions": record_actions,
                 "keepalive": keepalive,
                 "alias": alias,
+                "fast": fast,
+                "version": version,
             },
             headers=headers,
         ) as response:
@@ -124,6 +130,7 @@ class Plato:
                 env_id=env_id,
                 id=data["job_id"],
                 alias=data.get("alias"),
+                fast=fast,
             )
 
     async def get_job_status(self, job_id: str) -> Dict[str, Any]:
@@ -212,6 +219,7 @@ class Plato:
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
         load_authenticated: bool = False,
+        **kwargs,
     ) -> Dict[str, Any]:
         """Reset an environment with an optional new task.
 
@@ -232,6 +240,7 @@ class Plato:
             "test_case_public_id": task.public_id if task else None,
             "agent_version": agent_version,
             "load_browser_state": load_authenticated,
+            **kwargs,
         }
         start_time = time.time()
         async with self.http_session.post(
@@ -456,6 +465,8 @@ class Plato:
                     env_id=t["simulator"]["name"],
                     average_time=t.get("averageTimeTaken"),
                     average_steps=t.get("averageStepsTaken"),
+                    num_validator_human_scores=t.get("defaultScoringConfig", {}).get("num_sessions_used", 0),
+                    default_scoring_config=t.get("defaultScoringConfig", {}),
                 )
                 for t in test_cases
             ]
