@@ -1,6 +1,5 @@
 import os
 from plato.models.task import CustomEvalConfig
-from pydantic import Field
 from plato.models import PlatoTask, EvaluationResult
 from typing import List, Optional, Type, Dict, Any, TYPE_CHECKING
 import time
@@ -52,6 +51,7 @@ class SyncPlatoEnvironment:
         env_id: Optional[str] = None,
         alias: Optional[str] = None,
         active_session: Optional[str] = None,
+        fast: bool = False,
     ):
         self._client = client
         self.id = id
@@ -60,46 +60,62 @@ class SyncPlatoEnvironment:
         self._run_session_id = active_session
         self._heartbeat_thread = None
         self._stop_heartbeat = False
+        self.fast = fast
 
-    def login(self, page: Page) -> None:
+    def login(self, page: Page, throw_on_login_error: bool = False) -> None:
         """Login to the environment using authentication config.
-        
+
         Args:
             page (Page): The Playwright page to authenticate
         """
         from plato.models.flow import Simulator
         from plato.sync_flow_executor import SyncFlowExecutor
 
-        # Create S3 client
-        s3_client = boto3.client('s3')
-        
+        # Create S3 client configured for unsigned requests (public buckets)
+        try:
+            from botocore.config import Config  # type: ignore
+            from botocore import UNSIGNED  # type: ignore
+
+            s3_client = boto3.client("s3", config=Config(signature_version=UNSIGNED))
+        except ImportError:
+            # Fallback if botocore imports fail - this shouldn't happen with boto3 installed
+            raise PlatoClientError("boto3 and botocore are required for S3 access")
+
         # Ensure the temp directory exists
-        temp_dir = os.path.join('/tmp', self.env_id)
+        temp_dir = os.path.join("/tmp", self.env_id)
         os.makedirs(temp_dir, exist_ok=True)
-        
+
         # Download the scripts file from S3
         s3_client.download_file(
-            'plato-sim-scripts', 
+            "plato-sim-scripts",
             os.path.join(self.env_id, "scripts.yaml"),
-            os.path.join(temp_dir, "scripts.yaml")
+            os.path.join(temp_dir, "scripts.yaml"),
         )
-        
+
         # Load and parse the scripts file
         with open(os.path.join(temp_dir, "scripts.yaml"), "r") as f:
             scripts = yaml.safe_load(f)
             simulator = Simulator.model_validate(scripts)
 
         # Get base dataset and login flow
-        base_dataset = next((dataset for dataset in simulator.datasets if dataset.name == "base"), None)
+        base_dataset = next(
+            (dataset for dataset in simulator.datasets if dataset.name == "base"), None
+        )
         if not base_dataset:
             raise PlatoClientError("No base dataset found")
 
-        login_flow = next((flow for flow in simulator.flows if flow.name == "login"), None)
+        login_flow = next(
+            (flow for flow in simulator.flows if flow.name == "login"), None
+        )
         if not login_flow:
             raise PlatoClientError("No login flow found")
 
         flow_executor = SyncFlowExecutor(page, login_flow, base_dataset, logger=logger)
-        flow_executor.execute_flow()
+        if not flow_executor.execute_flow():
+            if throw_on_login_error:
+                raise PlatoClientError("Failed to login")
+            else:
+                logger.warning("Failed to login")
 
     def wait_for_ready(self, timeout: Optional[float] = None) -> None:
         """Wait for the environment to be ready.
@@ -203,7 +219,7 @@ class SyncPlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
         return self._client.get_cdp_url(self.id)
 
-    def reset(self, task: Optional[PlatoTask] = None, agent_version: Optional[str] = None, load_authenticated: bool = False) -> str:
+    def reset(self, task: Optional[PlatoTask] = None, agent_version: Optional[str] = None, load_authenticated: bool = False, **kwargs) -> str:
         """Reset the environment with an optional new task.
 
         Args:
@@ -214,7 +230,7 @@ class SyncPlatoEnvironment:
         Returns:
             str: The environment is reset and a new run session is created.
         """
-        response = self._client.reset_environment(self.id, task, agent_version, load_authenticated)
+        response = self._client.reset_environment(self.id, task, agent_version, load_authenticated, **kwargs)
         if task:
             self._current_task = task
 
@@ -410,7 +426,7 @@ class SyncPlatoEnvironment:
                 reason=result.get('reason', None),
                 diffs=result.get('diffs', None),
                 expected_mutations=result.get('expected_mutations', None),
-                actual_mutations=result.get('actual_mutations', None),
+                actual_mutations=result.get('mutations', None),
             )
 
     def log(self, log: dict, type: str = "info") -> None:
@@ -464,9 +480,11 @@ class SyncPlatoEnvironment:
             # Extract the base domain from the base_url
             if "localhost:8080" in self._client.base_url:
                 proxy_server = "http://localhost:8888"
+            elif "dev.plato.so" in self._client.base_url:
+                proxy_server = "https://dev.proxy.plato.so"
             elif "staging.plato.so" in self._client.base_url:
                 proxy_server = "https://staging.proxy.plato.so"
-            elif "plato.so" in self._client.base_url and "staging" not in self._client.base_url:
+            elif "plato.so" in self._client.base_url and "staging" not in self._client.base_url and "dev" not in self._client.base_url:
                 proxy_server = "https://proxy.plato.so"
             else:
                 raise PlatoClientError("Unknown base URL")
@@ -485,6 +503,7 @@ class SyncPlatoEnvironment:
         Returns:
             str: The public URL for this environment based on the deployment environment.
                  Uses alias if available, otherwise uses environment ID.
+                 - Dev: https://{alias|env.id}.dev.sims.plato.so
                  - Staging: https://{alias|env.id}.staging.sims.plato.so
                  - Production: https://{alias|env.id}.sims.plato.so
                  - Local: http://localhost:8081/{alias|env.id}
@@ -495,13 +514,15 @@ class SyncPlatoEnvironment:
         try:
             # Use alias if available, otherwise use environment ID
             identifier = self.alias if self.alias else self.id
-            
+
             # Determine environment based on base_url
             if "localhost:8080" in self._client.base_url:
                 return f"http://localhost:8081/{identifier}"
+            elif "dev.plato.so" in self._client.base_url:
+                return f"https://{identifier}.dev.sims.plato.so"
             elif "staging.plato.so" in self._client.base_url:
                 return f"https://{identifier}.staging.sims.plato.so"
-            elif "plato.so" in self._client.base_url and "staging" not in self._client.base_url:
+            elif "plato.so" in self._client.base_url and "staging" not in self._client.base_url and "dev" not in self._client.base_url:
                 return f"https://{identifier}.sims.plato.so"
             else:
                 raise PlatoClientError("Unknown base URL")
@@ -532,7 +553,7 @@ class SyncPlatoEnvironment:
         return self._client.backup_environment(self.id)
 
     @staticmethod
-    def from_id(client: "SyncPlato", id: str) -> "SyncPlatoEnvironment":
+    def from_id(client: "SyncPlato", id: str, fast: bool = False) -> "SyncPlatoEnvironment":
         """Create a new environment from an ID.
 
         Returns:
@@ -542,9 +563,11 @@ class SyncPlatoEnvironment:
         active_session = None
         try:
             active_session = client.get_active_session(id)
-        except Exception as e:
+        except Exception:
             logger.warning(
                 f"No active session found for job {id}, remember to reset the environment to use / evaluate."
             )
 
-        return SyncPlatoEnvironment(client, id, active_session=active_session)
+        env = SyncPlatoEnvironment(client, id, active_session=active_session, fast=fast)
+        env._start_heartbeat()
+        return env
