@@ -69,6 +69,8 @@ class SyncPlato:
         env_config: Optional[Dict[str, Any]] = None,
         keepalive: bool = False,
         alias: Optional[str] = None,
+        fast: bool = False,
+        version: Optional[str] = None,
     ) -> SyncPlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -83,6 +85,8 @@ class SyncPlato:
             env_config (Optional[Dict[str, Any]]): Environment configuration.
             keepalive (bool): If true, jobs will not be killed due to heartbeat failures.
             alias (Optional[str]): Optional alias for the job group.
+            fast (bool): Fast mode flag.
+            version (Optional[str]): Optional version of the environment.
 
         Returns:
             SyncPlatoEnvironment: The created environment instance.
@@ -104,6 +108,8 @@ class SyncPlato:
                 "record_actions": record_actions,
                 "keepalive": keepalive,
                 "alias": alias,
+                "fast": fast,
+                "version": version,
             },
         )
         response.raise_for_status()
@@ -113,6 +119,7 @@ class SyncPlato:
             env_id=env_id,
             id=data["job_id"],
             alias=data.get("alias"),
+            fast=fast,
         )
 
     def get_job_status(self, job_id: str) -> Dict[str, Any]:
@@ -190,6 +197,7 @@ class SyncPlato:
         task: Optional[PlatoTask] = None,
         agent_version: Optional[str] = None,
         load_authenticated: bool = False,
+        **kwargs,
     ) -> Dict[str, Any]:
         """Reset an environment with an optional new task.
 
@@ -209,6 +217,7 @@ class SyncPlato:
             "test_case_public_id": task.public_id if task else None,
             "agent_version": agent_version,
             "load_browser_state": load_authenticated,
+            **kwargs,
         }
         start_time = time.time()
         response = self.http_session.post(
@@ -428,6 +437,8 @@ class SyncPlato:
                 env_id=t["simulator"]["name"],
                 average_time=t.get("averageTimeTaken"),
                 average_steps=t.get("averageStepsTaken"),
+                num_validator_human_scores=t.get("defaultScoringConfig", {}).get("num_sessions_used", 0),
+                default_scoring_config=t.get("defaultScoringConfig", {}),
             )
             for t in test_cases
         ]
